Downloading this python package will also download the Eicar file as part of the python package https://www.eicar.org/download-anti-malware-testfile/.

The Eicar file is a file used widely to test anti-malware software against malware and viruses. The Eicar file downloaded as part of this package is not malware but most anti-malware solutions will detect the Eicar file as malware or a virus and will trigger an alert. Please use this package with caution. 

This python package was created for testing purposes. Please use with caution as it will trigger alerts. 